Branches Out of Sync — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# Branches Out of Sync

When reconfiguring a checkout, tree or branch into a lightweight checkout, a local branch must be destroyed. (For checkouts, this is the local branch that serves primarily as a cache.) If the branch-to-be-destroyed does not have the same last revision as the new reference branch for the lightweight checkout, data could be lost, so Breezy refuses.

How you deal with this depends on why the branches are out of sync.

If you have a checkout and have done local commits, you can get back in sync by running “brz update” (and possibly “brz commit”).

If you have a branch and the remote branch is out-of-date, you can push the local changes using “brz push”. If the local branch is out of date, you can do “brz pull”. If both branches have had changes, you can merge, commit and then push your changes. If you decide that some of the changes aren’t useful, you can “push –overwrite” or “pull –overwrite” instead.